@@ -255,13 +255,13 @@ class MalwareDetectionClient:
         """
         def yara_version_ok(yara):
             # Check the installed yara version >= MIN_YARA_VERSION
-            installed_yara_version = call([[yara, '--version']]).strip()
+            self.yara_version = call([[yara, '--version']]).strip()
             try:
-                self.yara_version = '.'.join(installed_yara_version.split('.')[:2])  # Eg 4.2.0 becomes 4.2
-                if float(self.yara_version) < float(MIN_YARA_VERSION[:3]):
+                # Check the installed yara X.Y version > the minimal recommended yara version
+                if float('.'.join(self.yara_version.split('.')[:2])) < float(MIN_YARA_VERSION[:3]):
                     raise RuntimeError("Found %s with version %s, but malware-detection requires version >= %s\n"
                                        "Please install a later version of yara."
-                                       % (yara, installed_yara_version, MIN_YARA_VERSION))
+                                       % (yara, self.yara_version, MIN_YARA_VERSION))
             except RuntimeError as e:
                 logger.error(str(e))
                 exit(constants.sig_kill_bad)
@@ -620,11 +620,10 @@ class MalwareDetectionClient:
             logger.error("Couldn't access the insights-client configuration")
             exit(constants.sig_kill_bad)
 
-        signatures_file = default_signatures_file = 'signatures.yar'
-        if hasattr(self, 'yara_version'):
-            signatures_file = 'signatures-%s.yar' % self.yara_version
+        signatures_file = 'signatures.yar'
+        signatures_file += '?yara_version=' + self.yara_version if hasattr(self, 'yara_version') else ''
         if not self.rules_location:
-            self.rules_location = "https://console.redhat.com/api/malware-detection/v1/" + signatures_file
+            self.rules_location = 'https://console.redhat.com/api/malware-detection/v1/' + signatures_file
             if '/redhat_access/' in self.insights_config.base_url:
                 # Satellite URLs have '/redhat_access/' in the base_url config option
                 self.rules_location = self.insights_config.base_url + '/malware-detection/v1/' + signatures_file
@@ -655,11 +654,6 @@ class MalwareDetectionClient:
             self.insights_config.cert_verify = True
             conn = InsightsConnection(self.insights_config)
             response = conn.get(self.rules_location, log_response_text=log_rule_contents)
-            if response.status_code == 404 and not (self.test_scan or signatures_file == default_signatures_file):
-                # Got a 404 with the 'signatures-X.Y.yar' file, so try with just 'signatures.yar' instead
-                logger.debug("Couldn't find %s file, trying %s instead", signatures_file, default_signatures_file)
-                self.rules_location = self.rules_location.replace(signatures_file, default_signatures_file)
-                response = conn.get(self.rules_location, log_response_text=log_rule_contents)
             if response.status_code != 200:
                 logger.error("%s %s: %s", response.status_code, response.reason, response.text)
                 exit(constants.sig_kill_bad)
