@@ -17,6 +17,12 @@ class LsPci(list):
     Combines the Parser LsPci of ``/sbin/lspci -k`` command and Parser
     LsPciVmmkn of ``/sbin/lspci -vmmkn`` command.
 
+    .. note::
+        In case the ``lspci -k`` sometimes outputs the `Slot` in the full
+        format of ``domain:bus:device.function``, and the ``lspci -k`` is more
+        common than ``lspci -vmmkn``, so this combiner will take the `Slot` of
+        the `lspci -k` as the key.
+
     Typical output of the ``lspci -k`` command is::
 
         00:00.0 Host bridge: Intel Corporation Haswell-ULT DRAM Controller (rev 09)
@@ -119,12 +125,17 @@ class LsPci(list):
                 dev = dev.copy()
                 if lspci_k and dev['Slot'] in lspci_k:
                     # use the local copy to prevent from writing back to the parser
-                    dev_k = lspci_k.data[dev['Slot']].copy()
+                    dev_k = [v for v in lspci_k.data.values() if v['Slot'].endswith(dev['Slot'])][0].copy()
+                    # Since the 'lspci -k' is a more common command than the
+                    #  'lspci -vmmkn', the following line should be commented
+                    #  out to use the 'Slot' in 'lspci -k' as the 'Slot' in
+                    #  this combiner:
+                    # dev_k.pop('Slot') if 'Slot' in dev_k else None
                     dev_k.pop('Kernel driver in use') if 'Kernel driver in use' in dev_k else None
                     dev_k.pop('Kernel modules') if 'Kernel modules' in dev_k else None
                     dev.update(dev_k)
                 self.append(dev)
-            self._pci_dev_list = lspci_vmmkn.pci_dev_list
+            self._pci_dev_list = (lspci_k if lspci_k else lspci_vmmkn).pci_dev_list
         else:
             for dev in lspci_k.data.values():
                 # use the local copy to prevent from writing back to the parser
