@@ -5,6 +5,7 @@ from insights.core.plugins import datasource
 from insights.core.spec_factory import DatasourceProvider
 from insights.client.apps.malware_detection import MalwareDetectionClient
 from insights.client.config import InsightsConfig
+from insights.client import auto_config
 
 
 class MalwareDetectionSpecs(Specs):
@@ -17,6 +18,7 @@ class MalwareDetectionSpecs(Specs):
         try:
             # Only run malware-detection if it was passed as an option to insights-client
             insights_config = InsightsConfig().load_all()
+            auto_config.try_auto_configuration(insights_config)
             if not (insights_config and hasattr(insights_config, 'app') and insights_config.app == 'malware-detection'):
                 raise SkipComponent
             mdc = MalwareDetectionClient(insights_config)
